﻿using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Security.Permissions;

namespace SpotnetMonitor
{
    static class SpotnetWatcher
    {
        #region Fields

        private static string SpotnetWatchdogPath;
        private static string SpotsFolder;

        #endregion

        #region Constructors

        static SpotnetWatcher()
        {
            SpotnetWatchdogPath = Path.Combine(Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location), "SpotnetWatchdog.exe");
            SpotsFolder = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.CommonApplicationData), "Spotnet");
        }

        #endregion

        #region Public Methods

        [PermissionSet(SecurityAction.Demand, Name = "FullTrust")]
        public static void Run()
        {
            //setup file watcher to check for changes in a .spots file used by Spotnet
            FileSystemWatcher watcher = new FileSystemWatcher(SpotsFolder, "*.spots");
            watcher.NotifyFilter = NotifyFilters.LastWrite;
            watcher.Changed += new FileSystemEventHandler(SpotnetFile_OnChanged);

            //enable watching
            watcher.EnableRaisingEvents = true;
        }

        static void SpotnetFile_OnChanged(object sender, FileSystemEventArgs e)
        {
            if (File.Exists(SpotnetWatchdogPath))
            {
                //start Spotnet Watchdog
                Process.Start(SpotnetWatchdogPath, "-swr");
            }
        }

        #endregion
    }
}
